@@ -1,9 +1,9 @@
-"""Tasmota discovery."""
+"""Tasmota switch."""
 import logging
 
 import attr
 
-from hatasmota.const import CONF_MAC
+from hatasmota.const import CONF_MAC, CONF_OPTIONS, OPTION_HASS_LIGHT
 from hatasmota.entity import (
     TasmotaAvailability,
     TasmotaAvailabilityConfig,
@@ -11,15 +11,16 @@ from hatasmota.entity import (
     TasmotaEntityConfig,
 )
 from hatasmota.utils import (
-    get_config_friendlyname,
+    config_get_friendlyname,
     get_state_power,
     get_topic_command_power,
+    get_topic_command_state,
     get_topic_tele_state,
     get_topic_tele_will,
-    get_state_offline,
-    get_state_online,
-    get_state_power_off,
-    get_state_power_on,
+    config_get_state_offline,
+    config_get_state_online,
+    config_get_state_power_off,
+    config_get_state_power_on,
 )
 
 _LOGGER = logging.getLogger(__name__)
@@ -29,27 +30,31 @@ _LOGGER = logging.getLogger(__name__)
 class TasmotaRelayConfig(TasmotaAvailabilityConfig, TasmotaEntityConfig):
     """Tasmota relay configuation."""
 
-    command_topic: str = attr.ib()
+    command_power_topic: str = attr.ib()
+    is_light: bool = attr.ib()
+    poll_topic = attr.ib()
     state_power_off: str = attr.ib()
     state_power_on: str = attr.ib()
     state_topic: str = attr.ib()
-    unique_id: str = attr.ib()
 
     @classmethod
-    def from_discovery_message(cls, config, idx):
+    def from_discovery_message(cls, config, idx, platform):
         """Instantiate from discovery message."""
         return cls(
-            mac=config[CONF_MAC],
+            endpoint="relay",
             idx=idx,
-            friendly_name=get_config_friendlyname(config, idx),
+            friendly_name=config_get_friendlyname(config, platform, idx),
+            mac=config[CONF_MAC],
+            platform=platform,
             availability_topic=get_topic_tele_will(config),
-            availability_offline=get_state_offline(config),
-            availability_online=get_state_online(config),
-            command_topic=get_topic_command_power(config, idx),
-            state_power_off=get_state_power_off(config),
-            state_power_on=get_state_power_on(config),
+            availability_offline=config_get_state_offline(config),
+            availability_online=config_get_state_online(config),
+            command_power_topic=get_topic_command_power(config, idx),
+            is_light=config[CONF_OPTIONS][OPTION_HASS_LIGHT] == 1,
+            poll_topic=get_topic_command_state(config),
+            state_power_off=config_get_state_power_off(config),
+            state_power_on=config_get_state_power_on(config),
             state_topic=get_topic_tele_state(config),
-            unique_id=f"{config[CONF_MAC]}_switch_{idx}",
         )
 
 
@@ -60,8 +65,14 @@ class TasmotaRelay(TasmotaAvailability, TasmotaEntity):
         """Initialize."""
         self._on_state_callback = None
         self._sub_state = None
+        self.light_type = None
         super().__init__(**kwds)
 
+    def poll_status(self):
+        """Poll for status."""
+        payload = ""
+        self._mqtt_client.publish_debounced(self._cfg.poll_topic, payload)
+
     def set_on_state_callback(self, on_state_callback):
         """Set callback for state change."""
         self._on_state_callback = on_state_callback
@@ -96,15 +107,10 @@ class TasmotaRelay(TasmotaAvailability, TasmotaEntity):
         """Unsubscribe to all MQTT topics."""
         self._sub_state = await self._mqtt_client.unsubscribe(self._sub_state)
 
-    @property
-    def unique_id(self):
-        """Return unique_id."""
-        return f"{self._cfg.mac}_switch_{self._cfg.idx}"
-
     def set_state(self, state):
         """Turn the relay on or off."""
         payload = self._cfg.state_power_on if state else self._cfg.state_power_off
         self._mqtt_client.publish(
-            self._cfg.command_topic,
+            self._cfg.command_power_topic,
             payload,
         )
